@@ -1,7 +1,7 @@
 __author__ = "SutandoTsukai181"
 __copyright__ = "Copyright 2021, SutandoTsukai181"
 __license__ = "MIT"
-__version__ = "1.4.2"
+__version__ = "1.4.3"
 
 import struct
 from contextlib import contextmanager
@@ -244,7 +244,7 @@ class BinaryReader:
         If size is not given, will read until the first null byte (which the position will be set after).\n
         If encoding is `None` (default), will use the BinaryReader's encoding.
         """
-        encode = self.__encoding if encoding is None else encoding
+        encode = encoding or self.__encoding
 
         if size is None:
             string = bytearray()
@@ -261,6 +261,26 @@ class BinaryReader:
 
         return self.read_bytes(size).split(b'\x00', 1)[0].decode(encode)
 
+    def read_str_to_token(self, token: str, encoding=None) -> str:
+        """Reads a string until a string token is found.\n
+        If encoding is `None` (default), will use the BinaryReader's encoding.
+        """
+        encode = encoding or self.__encoding
+
+        i = 0
+        string = bytearray()
+        token_bytes = token.encode(encode)
+        token_size = len(token_bytes)
+        while self.__idx < len(self.__buf):
+            string.append(self.__buf[self.__idx])
+            self.__idx += 1
+            if token_bytes == string[i : i + token_size]:
+                break
+            if len(string) >= token_size:
+                i += 1
+
+        return string.split(b'\x00', 1)[0].decode(encode)
+
     def read_int64(self, count=None) -> Union[int, Tuple[int]]:
         """Reads a signed 64-bit integer.\n
         If count is given, will return a tuple of values instead of 1 value.
@@ -395,8 +415,7 @@ class BinaryReader:
         If encoding is `None` (default), will use the BinaryReader's encoding.\n
         Returns the number of bytes written (including the null byte if it was added).
         """
-        bytes_obj = string.encode(
-            self.__encoding if encoding is None else encoding) + (b'\x00' if null else b'')
+        bytes_obj = string.encode(encoding or self.__encoding) + (b'\x00' if null else b'')
         self.write_bytes(bytes_obj)
         return len(bytes_obj)
 
@@ -410,10 +429,7 @@ class BinaryReader:
         if size < 0:
             raise ValueError('size cannot be negative')
 
-        bytes_obj = string.encode(
-            self.__encoding if encoding is None else encoding)[:size] + (b'\x00' * max(0, size - len(string)))
-        self.write_bytes(bytes_obj)
-        return len(bytes_obj)
+        self.write_bytes(string.encode(encoding or self.__encoding)[:size].ljust(size, b'\x00'))
 
     def write_int64(self, value: int) -> None:
         """Writes a signed 64-bit integer.\n
